@@ -61,7 +61,7 @@
 
 MC <- function(yhat, y, metrics=FALSE){
 
-  if(class(yhat)!=class(y)){
+  if(any(class(yhat)!=class(y))){
   yhat <- as.numeric(yhat)
   y <- as.numeric(y)
   }
