@@ -9,6 +9,7 @@ summary.Optim <- function(object, rankmodel=1, ...)
   switch (object[[1]],
           "LM" = {summarylm(object,rankmodel)},
           "GLM" = {summaryglm(object,rankmodel)},
+          "LMM" = {summarylmm(object,rankmodel)},
           "CART"={summarycart(object,rankmodel)},
           "DA"={summaryda(object,rankmodel)},
           "NN" = {summarynn(object,rankmodel)},
@@ -21,30 +22,35 @@ summarylm <- function(x,rankmodel=1){
 stats::summary.lm(x[[3]][[rankmodel]])
 }
 
-## Print GLM Information to show the print
+## Summary GLM Information to show the print
 summaryglm <- function(x,rankmodel=1){
   stats::summary.glm(x[[3]][[rankmodel]])
 
 }
 
-## Print CART Information to show the print
+## Summary LMM Information to show the print
+summarylmm <- function(x,rankmodel=1){
+  summary(x[[3]][[rankmodel]])
+
+}
+## Summary CART Information to show the print
 summarycart <- function(x,rankmodel=1){
   summary(x[[3]][[rankmodel]])
 
 }
 
-## Print DA Information to show the print
+## Summary DA Information to show the print
 summaryda <- function(x,rankmodel=1){
   print(x[[3]][[rankmodel]])
 
 }
 
-## Print SVM Information to show the print
+## Summary SVM Information to show the print
 summarysvm <- function(x,rankmodel=1){
   summary(x[[3]][[rankmodel]])
 }
 
-## Print NN Information to show the print
+## Summary NN Information to show the print
 summarynn <- function(x,rankmodel=1){
   summary(x[[3]][[rankmodel]])
 }
